User guide
==========

**earthkit-transforms** is a library of software tools to support people
working with climate and meteorology data.It is made of sub-modules desigined
for  transformations of data in specific domains.
For example, the temporal module contains methods for aggregation and
statistics analysis accross time dimensions/coordinates.

.. toctree::
   :maxdepth: 1

   spatial
   temporal
   climatology
